function cutsets = LP_cutsets(cont_results,demand)
    
    %Retrieve necessary variables from the contingency analysis:
    SAC=cont_results.SAC(3:end,1:end);
    comp_out=full(cont_results.comp_out);
    cutsets=struct;
    
    %Loop through all load points:
    for i = 1:size(SAC,2)
        load_point =strcat('load',num2str(i));
        load = struct; 
        sets= {}; 
        SAC_id={};
       
        %Loop through every fault combination:
        for j = 1:size(SAC,1)
          
            %Check if there is loss of load: 
            if demand(i) > SAC(j,i) 
                
                %Find components in the cut set and add at the end of the
                %cell "sets":
                sets{end+1} = find(comp_out(j,:));
                SAC_id{end+1} = j;  
            end
        end
        
        %If a load point has no loss of load. Add to struct: 
        if isempty(sets)
            cutsets = setfield(cutsets,load_point,{});
            continue
        end
        
         %check if any cut set is not minimal: 
         combinations =  combnk([1:length(sets)],2);  %every possible combination
         index = ones(length(sets),1);  
         
            %Loops thorough every combination of cut sets to check if a cut
            %set is a sub set of another cut set: 
            for k = 1:length(combinations)
                set_1 = sets{combinations(k,1)};
                set_2 = sets{combinations(k,2)}; 
                    if length(set_1) < length(set_2)
                        shortest= set_1;
                        longest = set_2 ;
                        id=combinations(k,2);
                    else
                        shortest=set_2; 
                        longest = set_1;
                        id=combinations(k,1);
                    end
                %Checks if the shortest subset is a subset of the longest
                %subset. (f.eks 1. order contingency is a subset of the 
                %cut set of a 2. order contingency:  
                a = ismember(shortest,longest);
                    if  sum(a) == length(a) 
                         index(id) = 0; 
                    end
            end
                 
            %Removes all sets that are not minimal:
            min_cut = sets(index == 1); 
            SAC_id = SAC_id(index==1);
           
            %Adds results to load struct.
            load = setfield(load,'min_cut',min_cut);
            load = setfield(load, 'SAC_id' , SAC_id); 
         
            %Add load struct to cut sets struct
            cutsets = setfield(cutsets,load_point,load);            
    end
    
end
                
                         
                           
                           
                            
               
           
                        
                        
            
           
            

