function cut_set_res = cut_set_indices(eq_values)

    %Calculates ENS for each minimal cut set
    %Only one operational state is included
    
    %Retrieves cut set parameters in a cell structure: 
    cut_set = struct2cell(eq_values) ; 
   
    %Loops through every load point:
    for i = 1:length(cut_set)       
        
        
        %If no loss of load at load point, keep empty. 
        if isempty(cut_set(i))   
           continue
        end
        
        %Loops through every minimal cut set: 
        for j = 1:size(cut_set{i},2) 
            
            %Retrieves known parameters from cut set: 
            P_int = cut_set{i}{j}.P_int ;
            lambda_eq = cut_set{i}{j}.lambda_eq ;
            r_eq = cut_set{i}{j}.r_eq;
            
            %Calculates indices:
            ENS = lambda_eq * r_eq * P_int ; %[MWh/year]
            P_int_c = P_int*lambda_eq;
            
            %Includes calculated indices to results:
            cut_set{i}{j}.ENS = ENS;  
            cut_set{i}{j}.P_int_c = P_int_c ; 
            
        end 
        
    end
     
    %Returns results to struct and names each loadpoint: 
    cut_set_res = cell2struct(cut_set(1:5),{'Load1','Load2','Load3','Load4','Load5'},1);

end