function lambda_approx = three_state_approx(line_1,line_2,trans_rates,lambda_avg,p_n,p_a,p_e,lambda_rbts,all_durations)

    %Define failure rate for both lines for all weather states:
    lambda_n_1 = lambda_rbts(line_1) + lambda_avg{line_1}(1)*8760;
    lambda_n_2 = lambda_rbts(line_2) + lambda_avg{line_2}(1)*8760;
    lambda_a_1 = lambda_rbts(line_1) + lambda_avg{line_1}(2)*8760;
    lambda_a_2 = lambda_rbts(line_2) + lambda_avg{line_2}(2)*8760;
    lambda_e_1 = lambda_rbts(line_1) + lambda_avg{line_1}(3)*8760;
    lambda_e_2 = lambda_rbts(line_2) + lambda_avg{line_2}(3)*8760;
    
    %Set expected repair time:
    r_1 = 11.420898198198216/8760;  
    r_2 = 11.420898198198216/8760;   


    %Define all possible transition rates:
    n_a_1 = trans_rates{line_1}(1,2);
    n_a_2 = trans_rates{line_2}(1,2);
    n_e_1 = trans_rates{line_1}(1,3);
    n_e_2 = trans_rates{line_2}(1,3); 
    a_n_1 = trans_rates{line_1}(2,1);
    a_n_2 = trans_rates{line_2}(2,1);
    a_e_1 = trans_rates{line_1}(2,3);
    a_e_2 = trans_rates{line_2}(2,3); 
    e_n_1 = trans_rates{line_1}(3,1);
    e_n_2 = trans_rates{line_2}(3,1);
    e_a_1 = trans_rates{line_1}(3,2);
    e_a_2 = trans_rates{line_2}(3,2);
    
%The following part calculates transition rates for each transition and
%takes into account if one or both are zero: 

    %From Normal to Adverse
    if n_a_1 == 0 && n_a_2 == 0               
        disp('no transition on n_a');
        n_a = 0;
    elseif n_a_1 == 0
        n_a = n_a_2;     
    elseif n_a_2 == 0
        n_a = n_a_1  ;   
    else
        n_a = ((n_a_1 + n_a_2)/2);  
    end
    
    %From Normal to Extreme:
    if n_e_1 == 0 && n_e_2 == 0        
        disp('no transition on n_e');
        n_e = 0; 
    elseif n_e_1 == 0
        n_e = n_e_2;    
    elseif n_e_2 == 0
        n_e = n_e_1;    
    else
    n_e = ((n_e_1 + n_e_2)/2);  
    end
    
    
    %From Adverse to Normal
    if a_n_1 == 0 && a_n_2 == 0
        disp('no transition on a_n');
        a_n = 0; 
    elseif a_n_1 == 0
        a_n = a_n_2  ;   
    elseif a_n_2 == 0
        a_n = a_n_1  ; 
    else
        a_n = ((a_n_1 + a_n_2)/2);  
    end
    
    %From Adverse to Extreme: 
    if a_e_1 == 0 && a_e_2 == 0          
        disp('no transition on a_e');
        a_e = 0; 
    elseif a_e_1 == 0
        a_e = a_e_2 ;  
    elseif a_e_2 == 0
        a_e = a_e_1 ;    
    else
        a_e = ((a_e_1 + a_e_2)/2) ;  
    end

    %From Extreme to normal: 
    if e_n_1 == 0 && e_n_2 == 0             
        disp('no transition on e_n');
        e_n = 0; 
    elseif e_n_1 == 0
        e_n = e_n_2 ;    
    elseif e_n_2 == 0
        e_n = e_n_1 ;   
    else
        e_n = ((e_n_1 + e_n_2)/2) ;  
    end
    
  

    %From Extreme to Adverse: 
    if e_a_1 == 0 && e_a_2 == 0         
        disp('no transition on n_a');
        e_a = 0; 
    elseif e_a_1 == 0
        e_a = e_a_2   ;  
    elseif e_a_2 == 0
        e_a = e_a_1 ;    
    else
        e_a = ((e_a_1 + e_a_2)/2) ;
    end



    %Calculates weather durations: 
    N = ((sum(all_durations{line_1}{1,2}) + sum(all_durations{line_1}{1,3}) + sum(all_durations{line_2}{1,2}) + sum(all_durations{line_2}{1,3})) ...   
        / (length(all_durations{line_1}{1,2}) + length(all_durations{line_1}{1,3}) + length(all_durations{line_2}{1,2}) + length(all_durations{line_2}{1,3})))/8760;
    
    A = ((sum(all_durations{line_1}{2,1}) + sum(all_durations{line_1}{2,3}) + sum(all_durations{line_2}{2,1}) + sum(all_durations{line_2}{2,3})) ...   
        / (length(all_durations{line_1}{2,1}) + length(all_durations{line_1}{2,3}) + length(all_durations{line_2}{2,1}) + length(all_durations{line_2}{2,3})))/8760;
    
    E = ((sum(all_durations{line_1}{3,1}) + sum(all_durations{line_1}{3,2}) + sum(all_durations{line_2}{3,1}) + sum(all_durations{line_2}{3,2})) ...   
        / (length(all_durations{line_1}{3,1}) + length(all_durations{line_1}{3,2}) + length(all_durations{line_2}{3,1}) + length(all_durations{line_2}{3,2})))/8760;

    %Both failures occur in normal weather:
    lambda_1 = p_n*(lambda_n_1*(1-exp(-lambda_n_2*r_1)) + lambda_n_2*(1-exp(-lambda_n_1*r_2)));

    %First failure in normal, second in adverse:
    lambda_2 = p_n*(lambda_n_1*(1-exp(-n_a*r_1))*exp(-lambda_n_2*r_1)*(1-exp(-lambda_a_2*A))...
    + lambda_n_2*(1-exp(-n_a*r_2))*exp(-lambda_n_1*r_2)*(1-exp(-lambda_a_1*A)));

    %First failure in normal, second in extreme:
    lambda_3 = p_n*(lambda_n_1*(1-exp(-n_e*r_1))*exp(-lambda_n_2*r_1)*(1-exp(-lambda_e_2*E))...
    + lambda_n_2*(1-exp(-n_e*r_2))*exp(-lambda_n_1*r_2)*(1-exp(-lambda_e_1*E)));

    %First failure in adverse, second in  normal:
    lambda_4 = p_a*(lambda_a_1*(1-exp(-a_n*A))*exp(-lambda_a_2*A)*(1-exp(-lambda_n_2*r_1))...
    + lambda_a_2*(1-exp(-a_n*A))*exp(-lambda_a_1*A)*(1-exp(-lambda_n_1*r_2)));

    %Both failure in adverse:
    lambda_5 = p_a*(lambda_a_1*(1-exp(-lambda_a_2*A)) + lambda_a_2*(1-exp(-lambda_a_1*A)));


    %First failure in adverse, second in extreme: 
    lambda_6 = p_a*(lambda_a_1*(1-exp(-a_e*A))*exp(-lambda_a_2*A)*(1-exp(-lambda_e_2*E))...
    + lambda_a_2*(1-exp(-a_e*A))*exp(-lambda_a_1*A)*(1-exp(-lambda_e_1*E)));


    %First failure in extreme, second in normal:
    lambda_7 = p_e*(lambda_e_1*(1-exp(-e_n*E))*exp(-lambda_e_2*E)*(1-exp(-lambda_n_2*r_1))...
    + lambda_e_2*(1-exp(-e_n*E))*exp(-lambda_e_1*E)*(1-exp(-lambda_n_1*r_2)));


    %First failure in extreme, second in adverse:
    lambda_8 = p_e*(lambda_e_1*(1-exp(-e_a*E))*exp(-lambda_e_2*E)*(1-exp(-lambda_a_2*A))...
    + lambda_e_2*(1-exp(-e_a*E))*exp(-lambda_e_1*E)*(1-exp(-lambda_a_1*A)));

    %Both failure occur in extreme weather: 
    lambda_9 = p_e*(lambda_e_1*(1-exp(-lambda_e_2*E)) + lambda_e_2*(1-exp(-lambda_e_1*E))); 

    %Calculates approximate failure rate for the system:
    lambda_approx = lambda_1 + lambda_2 + lambda_3 + lambda_4 + lambda_5 + lambda_6 + lambda_7 + lambda_8 + lambda_9;

    lambda = [lambda_1,lambda_2,lambda_3 ; lambda_4,lambda_5,lambda_6 ; lambda_7,lambda_8,lambda_9];

end